# Generated icons

These icons are generated by the script/project at https://github.com/voidlabs/versafix-social-icons
You can create support new socials and new styles by participating to the project.
